
-------------------------------------------------------------------------------------------------
<div class="row">
	<a href="https://liberalarts.utexas.edu/imhr/">
		<img src="./docs/source/_static/img/imhr.png" height="auto" width="100%" max-width="400px">
	</a>
<div>

-------------------------------------------------------------------------------------------------
[![PyPI Version](https://img.shields.io/pypi/v/imhr.svg)](https://pypi.org/project/imhr/)
[![License](https://img.shields.io/pypi/l/imhr.svg)](https://github.com/risoms/mdl/blob/master/LICENSE)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1313201.svg)](https://doi.org/10.1016/j.cct.2018.10.014)

mdl: an extensive suite for the exploration, visualization, and analysis of psychological data.
-------------------------------------------------------------------------------------------------

The mdl suite is funded by NIMH grant MH109600. 
Hsu, K. J., Caffey, K., Pisner, D., Shumake, J., Risom, S., Ray, K. L., . . . Beevers, C. G. (2018). 
	Attentional bias modification treatment for depression: Study protocol for a randomized controlled trial. 
	Contemporary Clinical Trials, 75, 59-66. doi:https://doi.org/10.1016/j.cct.2018.10.014

This suite was created at the [Institute for Mental Health Research](http://mdl.psy.utexas.edu/), at [the University of Texas at Austin](http://www.utexas.edu/) by [Semeon Risom](https://semeon.io).

Documentation
-------------
Online documentation is available [here](https://risoms.github.io/mdl/docs/build/py-modindex.html). 

Documentation include [examples](https://risoms.github.io/mdl/docs/build/examples/index.html), [API reference](https://risoms.github.io/mdl/docs/build/api/mdl.html), and other useful information.

Dependencies
------------
mdl requires the following dependencies:

-  [Python 3.6+](https://www.python.org/downloads/)
-  [numpy](http://www.numpy.org/)
-  [scipy](https://www.scipy.org/)
-  [PIL](https://pillow.readthedocs.io/en/stable/index.html)
-  [matplotlib](https://matplotlib.org)
-  [pywin32 (if using Windows](https://github.com/mhammond/pywin32)
-  [pyobjc (if using Mac OS](https://pythonhosted.org/pyobjc/)


Installation
------------

The latest stable release (and older versions) can be installed from ``PyPI``::

    pip install imhr

Alternatively, you can install the development version directly from ``github``::

    pip install git+https://github.com/risoms/IMHR-R33.git
